@@ -1,6 +1,6 @@
 """
 ===============
-PingdomLib v1.5
+PingdomLib v1.8
 ===============
 Written by: Kenneth Wilke <kenneth.wilke@gmail.com>
 
@@ -70,6 +70,8 @@ Contributors
 * Gertjan Oude Lohuis
 * Benjamin Boudreau
 * Britt Gresham
+* Allard Hoeve
+* Willem de Groot
 
 Special thanks
 ==============
